## How to contribute to emcee

### Expectations

emcee is developed and maintained in my spare time and, while I try to be
responsive, I don't always get to every issue immediately. If it has been more
than a week or two, feel free to ping me to try to get my attention. Do not
email me directly; all discussion should happen on [the mailing
list](https://groups.google.com/forum/#!forum/emcee-users).

### Did you find a bug?

**Ensure the bug was not already reported** by searching on GitHub under
[Issues](https://github.com/dfm/emcee/issues). If you're unable to find an
open issue addressing the problem, [open a new
one](https://github.com/dfm/emcee/issues/new). Be sure to include a **title
and clear description**, as much relevant information as possible, and the
simplest possible **code sample** demonstrating the expected behavior that is
not occurring.

### Did you write a patch that fixes a bug?

Open a new GitHub pull request with the patch. Ensure the PR description
clearly describes the problem and solution. Include the relevant issue number
if applicable.

### Do you intend to add a new feature or change an existing one?

First, read the [VISION](https://github.com/dfm/emcee/blob/main/VISION.md)
notes and make sure that your feature is consistent with those. In particular,
modifications of the core algorithm or additions of new algorithms are
unlikely to be approved. If your feature seems to be consistent, suggest it on
the [emcee-users mailing
list](https://groups.google.com/forum/#!forum/emcee-users) for some discussion
before opening a pull request.

### Do you have questions about the code or about MCMC in general?

**Do not open an issue.** Ask any questions on the [emcee-users mailing
list](https://groups.google.com/forum/#!forum/emcee-users).

Thanks!

[Dan](https://github.com/dfm)
